<?php
/*
Plugin Name: Agency Toolkit
Description: Lightweight and modular client site tools to empower your agency.
Version: 1.0.6
Author: Inspry
Author URI: https://www.inspry.com/
License: GPL v2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

// Standard WP check if direct
if ( ! function_exists( 'add_action' ) ) {
    exit();
}

// Register activation hook
register_activation_hook( __FILE__, 'inspry_toolkit_activation' );
function inspry_toolkit_activation() {
    // Set transient
    set_transient( 'inspry_toolkit_activation_notification', true, 5 );
}

// Add the activation notificaton
add_action( 'admin_notices', 'inspry_toolkit_activation_notification_notice' );
function inspry_toolkit_activation_notification_notice() {
    // Check for transient
    if ( get_transient( 'inspry_toolkit_activation_notification' ) ) {
        // Transient available, we can delete it now
        delete_transient( 'inspry_toolkit_activation_notification' );

        // Display notification
        ?>
        <div class="notice notice-success is-dismissible">
            <p style="font-weight: bold;">Agency Toolkit Activated</p>
            <p>Agency Toolkit plugin has been activated. You may visit your options page <strong><a href="<?php echo esc_url( get_admin_url() ); ?>admin.php?page=inspry-agency-toolkit">here</a></strong>.</p>
        </div>
        <?php
    }
}

// Include the options page file
include( plugin_dir_path( __FILE__ ) . 'options.php' );

// Loop through options and enable what is enabled
foreach ( $toolkit_options as $option ) {
    // Check if the option is enabled
    if ( get_option( 'inspry_toolkit_' . $option[ "name" ] ) == 1 ) {
        // Exclude limit admins file since there is none
        if ( $option[ "name" ] != 'limit_admins' ) {
            // Include the file that option is located in
            include( plugin_dir_path( __FILE__ ) . 'functions/' . $option[ "name" ] . '.php' );
        }
    }
    else {
        // Check for hard-coded options that we need to disable
        if ( $option[ "name" ] == 'secure_wpconfig' ) {
            // Include the disable function file
            include( plugin_dir_path( __FILE__ ) . 'functions/disable_secure_wpconfig.php' );
        }
    }
}
?>
