<?php
// Standard WP check if direct
if ( ! function_exists( 'add_action' ) ) {
    exit();
}

// Create all option settings
$toolkit_options = array(
    array(
        'name' => 'limit_admins',
        'description' => 'Limit the admins that can view the toolkit options page',
    ),
    array(
        'name' => 'maintenance_mode',
        'description' => 'Enable maintenance mode',
    ),
    array(
        'name' => 'enable_wp_debugger',
        'description' => 'Enable the WordPress debugger',
    ),
    array(
        'name' => 'limit_post_revisions',
        'description' => 'Limit or disable post revisions',
    ),
    array(
        'name' => 'backend_footer',
        'description' => 'Enable a custom agency footer with a name, URL and email in the WordPress Dashboard',
    ),
    array(
        'name' => 'backend_logo',
        'description' => 'Enable a custom agency logo on the WordPress login screen',
    ),
    array(
        'name' => 'remove_site_health',
        'description' => 'Hide Site Health from the WordPress backend',
    ),
    array(
        'name' => 'disable_editors',
        'description' => 'Disable theme and plugin editors',
    ),
    array(
        'name' => 'disable_installs_and_updates',
        'description' => 'Disable plugin and theme installs and updates',
    ),
    array(
        'name' => 'disable_auto_update_emails',
        'description' => 'Disable automatic update notification emails',
    ),
    array(
        'name' => 'disable_xml_rpc',
        'description' => 'Disable XML-RPC',
    ),
    array(
        'name' => 'disable_self_pingback',
        'description' => 'Disable self-pingbacks',
    ),
    array(
        'name' => 'disable_pingback_trackback_emails',
        'description' => 'Disable pingback and trackback notification emails',
    ),
    array(
        'name' => 'disable_emoticons',
        'description' => 'Disable emoticons',
    ),
    array(
        'name' => 'remove_rsd_links',
        'description' => 'Remove RSD links',
    ),
    array(
        'name' => 'hide_wordpress_version',
        'description' => 'Hide WordPress version generator in front-end source code',
    ),
    array(
        'name' => 'secure_wpconfig',
        'description' => 'Secure the wp-config.php file using .htaccess',
    ),
    array(
        'name' => 'change_email_sender',
        'description' => 'Globally change email sender',
    ),
);

// Add options menu
function inspry_toolkit_options_menu_item() {
    add_menu_page( 'Agency Toolkit Options', 'Agency Toolkit', 'manage_options', 'inspry-agency-toolkit', 'inspry_toolkit_options_page', 'dashicons-hammer', 80);
}
add_action( 'admin_menu', 'inspry_toolkit_options_menu_item') ;

// Register options
function inspry_toolkit_options_register() {
    // Get options
    global $toolkit_options;

    // Loop through each option to register
    foreach ( $toolkit_options as $option ) {
        // Register the option
        register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_' . $option[ "name" ] );
    }

    // Add custom settings as well
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_backend_footer_agency_name' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_backend_footer_agency_url' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_backend_footer_agency_email' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_backend_logo_image' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_limit_post_revisions_number' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_enable_wp_debugger_log' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_enable_wp_debugger_display' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_limit_admins' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_limit_admins_list' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_maintenance_mode_heading' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_maintenance_mode_sentence' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_change_email_sender_address' );
    register_setting( 'inspry_toolkit_options_group', 'inspry_toolkit_change_email_sender_name' );
}
add_action( 'admin_init', 'inspry_toolkit_options_register' );

// Include media uploader script function
function inspry_toolkit_options_page_enqueue() {
    wp_enqueue_media();
    wp_register_script( 'inspry_toolkit_options_page_script', plugins_url( 'js/options-page-script.js', __FILE__ ), array( 'jquery' ) );
    wp_enqueue_script( 'inspry_toolkit_options_page_script' );
}
add_action( 'admin_enqueue_scripts', 'inspry_toolkit_options_page_enqueue' );

// Add settings page content
function inspry_toolkit_options_page() {
    // Check if user is admin
    if ( is_admin() ) {
        // Check if limit admins option is enabled and that list is not empty (to avoid an admin locking themselves out)
        if ( get_option( 'inspry_toolkit_limit_admins' ) == 1 && ! empty( get_option( 'inspry_toolkit_limit_admins_list' ) ) ) {
            // Check if this admin is included in the array
            if ( in_array( get_current_user_id(), get_option( 'inspry_toolkit_limit_admins_list' ) ) ) {
                // Limit admins enabled and user is in list, display page
                inspry_toolkit_options_page_html();
            } else {
                // Limit admins enabled and user is not in list, display error
                inspry_toolkit_options_page_error();
            }
        } else {
            // Limit admins disabled and this user is an admin, display page
            inspry_toolkit_options_page_html();
        }
    } else {
        // User is not an admin role, display error
        inspry_toolkit_options_page_error();
    }
}

// Options page HTML and JS
function inspry_toolkit_options_page_html() {
    // Get options
    global $toolkit_options;
    ?>
    <div>
        <h2>Agency Toolkit Options</h2>
        <p>Check all of the options that you wish to enable or disable on this website.</p>
        <form method="post" action="options.php" id="inspry_toolkit_options_form">
            <?php settings_fields( 'inspry_toolkit_options_group' ); ?>
            <?php do_settings_sections( 'inspry_toolkit_options_group' ); ?>
                <table style="text-align: left;">
                    <?php
                    foreach ( $toolkit_options as $option ) {
                        // Get checked option
                        $checked = get_option( 'inspry_toolkit_' . $option[ "name" ] );

                        // Determine if checked or not
                        if ( $checked == 1 ) {
                            $checked = 'checked';
                        }
                        else {
                            $checked = '';
                        }

                        // Display option
                        ?>
                        <tr valign="top" class="inspry_toolkit_option_row_<?php echo esc_attr( $option[ 'name' ] ); ?>">
                            <td><input type="checkbox" id="<?php echo esc_attr( 'inspry_toolkit_' . $option[ "name" ] ); ?>" name="<?php echo esc_attr( 'inspry_toolkit_' . $option[ "name" ] ); ?>" value="1" <?php checked( 1, get_option( 'inspry_toolkit_' . $option["name"] ), false ); ?> <?php echo esc_html( $checked ); ?> /></td>
                            <th scope="row"><label for="<?php echo esc_attr( 'inspry_toolkit_' . $option[ "name" ] ); ?>"><?php echo esc_html( $option[ "description" ] ); ?></label></th>
                        </tr>
                        <?php

                        // Check if this option is one that will include custom settings
                        switch ( $option[ 'name' ] ) {
                            case 'backend_footer':
                                ?>
                                <tr valign="top" class="inspry_toolkit_backend_footer_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Agency Name</span>
                                        <input type="text" name="inspry_toolkit_backend_footer_agency_name" value="<?php echo esc_attr( get_option( 'inspry_toolkit_backend_footer_agency_name' ) ); ?>" />
                                    </td>
                                </tr>
                                <tr valign="top" class="inspry_toolkit_backend_footer_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Agency URL</span>
                                        <input type="text" name="inspry_toolkit_backend_footer_agency_url" value="<?php echo esc_url( get_option( 'inspry_toolkit_backend_footer_agency_url' ) ); ?>" />
                                    </td>
                                </tr>
                                <tr valign="top" class="inspry_toolkit_backend_footer_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Agency Email</span>
                                        <input type="text" name="inspry_toolkit_backend_footer_agency_email" value="<?php echo esc_attr( get_option( 'inspry_toolkit_backend_footer_agency_email' ) ); ?>" />
                                    </td>
                                </tr>
                                <?php
                                break;

                            case 'backend_logo':
                                ?>
                                <tr valign="top" class="inspry_toolkit_backend_logo_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Logo Image</span>
                                        <input type="text" name="inspry_toolkit_backend_logo_image" id="inspry_toolkit_backend_logo_image" value="<?php echo esc_url( get_option( 'inspry_toolkit_backend_logo_image' ) ); ?>" />
                                        <input type="button" id="upload_backend_logo_image_button" class="button-primary" value="Insert Image" />
                                    </td>
                                </tr>
                                <?php
                                break;

                            case 'limit_post_revisions':
                                ?>
                                <tr valign="top" class="inspry_toolkit_limit_post_revisions_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Limit Amount</span>
                                        <select name="inspry_toolkit_limit_post_revisions_number">
                                            <option value="0" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 0 ) { echo esc_attr( 'selected="selected"' ); } ?>>0 - Disable</option>
                                            <option value="1" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 1 ) { echo esc_attr( 'selected="selected"' ); } ?>>1</option>
                                            <option value="3" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 3 ) { echo esc_attr( 'selected="selected"' ); } ?>>3</option>
                                            <option value="5" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 5 ) { echo esc_attr( 'selected="selected"' ); } ?>>5</option>
                                            <option value="10" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 10 ) { echo esc_attr( 'selected="selected"' ); } ?>>10</option>
                                            <option value="15" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 15 ) { echo esc_attr( 'selected="selected"' ); } ?>>15</option>
                                            <option value="20" <?php if ( get_option( 'inspry_toolkit_limit_post_revisions_number' ) == 20 ) { echo esc_attr( 'selected="selected"' ); } ?>>20</option>
                                        </select>
                                    </td>
                                </tr>
                                <?php
                                break;

                            case 'enable_wp_debugger':
                                ?>
                                <tr valign="top" class="inspry_toolkit_enable_wp_debugger_custom_option">
                                    <th></th>
                                    <td>
                                        <input type="checkbox" id="inspry_toolkit_enable_wp_debugger_log" name="inspry_toolkit_enable_wp_debugger_log" value="1" <?php checked( 1, get_option( 'inspry_toolkit_enable_wp_debugger_log' ), false ); ?> <?php if ( get_option( 'inspry_toolkit_enable_wp_debugger_log' ) == 1 ) { echo esc_attr( 'checked' ); } ?> />
                                        <span style="font-weight: bold; display: inline-block;">Enable debugger log (logs to <?php echo esc_html( $_SERVER[ 'DOCUMENT_ROOT' ] ); ?>wp-content/debug.log)</span>
                                    </td>
                                </tr>
                                <tr valign="top" class="inspry_toolkit_enable_wp_debugger_custom_option">
                                    <th></th>
                                    <td>
                                        <input type="checkbox" id="inspry_toolkit_enable_wp_debugger_display" name="inspry_toolkit_enable_wp_debugger_display" value="1" <?php checked( 1, get_option( 'inspry_toolkit_enable_wp_debugger_display' ), false ); ?> <?php if ( get_option( 'inspry_toolkit_enable_wp_debugger_display' ) == 1 ) { echo esc_attr( 'checked' ); } ?> />
                                        <span style="font-weight: bold; display: inline-block;">Enable debugger display (displays errors on front-end)</span>
                                    </td>
                                </tr>
                                <?php
                                break;

                            case 'limit_admins':
                                ?>
                                <tr valign="top" class="inspry_toolkit_limit_admins_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Limited Admins</span>
                                        <select name="inspry_toolkit_limit_admins_list[]" multiple="multiple">
                                            <?php
                                            $admins = get_users( array( 'role' => 'administrator', 'order' => 'ASC', 'orderby' => 'ID' ) );
                                            foreach ( $admins as $admin ) {
                                                ?>
                                                <option value="<?php echo esc_attr( $admin->ID ); ?>" <?php if ( ! empty( get_option( 'inspry_toolkit_limit_admins_list' ) ) ) { if ( in_array( $admin->ID, get_option( 'inspry_toolkit_limit_admins_list' ) ) ) { echo esc_attr ( 'selected="selected"' ); } } ?>><?php echo esc_html( $admin->user_login ); ?></option>
                                                <?php
                                            }
                                            ?>
                                        </select>
                                    </td>
                                </tr>
                                <?php
                                break;

                            case 'maintenance_mode':
                                ?>
                                <tr valign="top" class="inspry_toolkit_maintenance_mode_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Maintenance mode heading</span>
                                        <input type="text" name="inspry_toolkit_maintenance_mode_heading" value="<?php echo esc_attr( get_option( 'inspry_toolkit_maintenance_mode_heading' ) ); ?>" />
                                    </td>
                                </tr>
                                <tr valign="top" class="inspry_toolkit_maintenance_mode_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Maintenance mode sentence</span>
                                        <input type="text" name="inspry_toolkit_maintenance_mode_sentence" value="<?php echo esc_attr( get_option( 'inspry_toolkit_maintenance_mode_sentence' ) ); ?>" />
                                    </td>
                                </tr>
                                <?php
                                break;

                            case 'change_email_sender':
                                ?>
                                <tr valign="top" class="inspry_toolkit_change_email_sender_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Email sender address</span>
                                        <input type="text" name="inspry_toolkit_change_email_sender_address" value="<?php echo esc_attr( get_option( 'inspry_toolkit_change_email_sender_address' ) ); ?>" />
                                    </td>
                                </tr>
                                <tr valign="top" class="inspry_toolkit_change_email_sender_custom_option">
                                    <th></th>
                                    <td>
                                        <span style="font-weight: bold; width: 100px; display: inline-block;">Email sender name</span>
                                        <input type="text" name="inspry_toolkit_change_email_sender_name" value="<?php echo esc_attr( get_option( 'inspry_toolkit_change_email_sender_name' ) ); ?>" />
                                    </td>
                                </tr>
                                <?php
                                break;
                        }
                    }
                    ?>
                </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Options error page HTML
function inspry_toolkit_options_page_error() {
    ?>
    <h1>Not authorized</h1>
    <p>You are not authorized to view this page. Please contact the site admin for more information.</p>
    <?php
}
?>
